@@ -34,11 +34,11 @@
 	if (!retval) {                                                  \
 		GnomeVFSResult result = pygnome_vfs_exception_check();  \
 		if ((signed)result >= 0) {                              \
+                        PyErr_Clear();                                  \
                         GILSTATE_RELEASE(state);                        \
 			return result;                                  \
 		} else if ((signed)result == -2) {                      \
 			PyErr_Print();                                  \
-			PyErr_Clear();                                  \
 		}                                                       \
                 GILSTATE_RELEASE(state);                                \
 		return GNOME_VFS_ERROR_GENERIC;                         \
@@ -946,7 +946,7 @@ do_check_same_fs  (GnomeVFSMethod  *method,
 	PyGILState_STATE state;
 	
 	pymethod = get_method_from_uri(a);
-	if (!pymethod->move_func) {
+	if (!pymethod->check_same_fs_func) {
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
 
@@ -954,7 +954,7 @@ do_check_same_fs  (GnomeVFSMethod  *method,
 	pyuri_a = pygnome_vfs_uri_new(gnome_vfs_uri_ref(a));
 	pyuri_b = pygnome_vfs_uri_new(gnome_vfs_uri_ref(b));	
 	pycontext = context_new(context);
-	retval = PyObject_CallObject(pymethod->move_func,
+	retval = PyObject_CallObject(pymethod->check_same_fs_func,
 				     Py_BuildValue("(NNN)",
 						   pyuri_a,
 						   pyuri_b,
@@ -1171,8 +1171,10 @@ do_file_control (GnomeVFSMethod       *method,
 GnomeVFSMethod *
 vfs_module_init (const char *method_name, const char *args)
 {
-	PyObject *instance, *class_object, *d, *m, *path;
+	PyObject *instance, *class_object, *d, *m;
+	PyObject *path, *py_vfs_dir, *py_home_dir;
 	char *full_name;
+	char *home_dir;
 	PyVFSMethod *pymethod;
 	PyGILState_STATE state = 0;
 	
@@ -1196,8 +1198,19 @@ vfs_module_init (const char *method_name, const char *args)
 	PyEval_InitThreads();
 	init_pygnomevfs();
 
+	py_vfs_dir = PyString_FromString(GNOME_VFS_PYTHON_DIR);
+
+	home_dir = g_strdup_printf("%s/.gnome2/vfs/pythonmethod",
+				   g_get_home_dir());
+	py_home_dir = PyString_FromString(home_dir);
+	g_free(home_dir);
+
 	path = PySys_GetObject("path");
-	PyList_Insert(path, 0, PyString_FromString(GNOME_VFS_PYTHON_DIR));
+	PyList_Insert(path, 0, py_vfs_dir);
+	PyList_Insert(path, 0, py_home_dir);
+
+	Py_DECREF(py_vfs_dir);
+	Py_DECREF(py_home_dir);
 
 	m = PyImport_ImportModule(g_strdup(method_name));
 	if (!m) {
@@ -1278,6 +1291,5 @@ vfs_module_init (const char *method_name, const char *args)
 void
 vfs_module_shutdown (GnomeVFSMethod *method)
 {
-	g_message("python:vfs_module_shutdown()");	
 	Py_Finalize();
 }
